@@ -39,9 +39,12 @@ class Folder;
 namespace Filelight
 {
 class Part;
+class SummaryWidget;
 
 class BrowserExtension : public KParts::BrowserExtension
 {
+    Q_OBJECT
+
 public:
     explicit BrowserExtension(Part*);
 };
@@ -80,7 +83,7 @@ private:
     void showSummary();
 
     QLayout            *m_layout;
-    QWidget            *m_summary;
+    SummaryWidget      *m_summary;
     BrowserExtension   *m_ext;
     StatusBarExtension *m_statusbar;
     RadialMap::Widget  *m_map;
